# pylantool

python编程中的一些常用工具函数集。


## install
```pip install git+https://gitee.com/mysticalwing/pylantool.git --upgrade```

## introduction && usage
目前主要包含5个模块，分别如下

- decorator 一些常用的装饰器
- fs 和文件系统交互的一些常用函数，另外如果需要更丰富的文件系统功能，推荐安装PyFileSystem2
- io json和pickle文件的简单读取函数
- profiler 包含对程序进行性能分析的一些工具函数，目前只包含计时器
- logger 简单的日志配置模块


